=============================
pymmwr
=============================

.. image:: https://img.shields.io/travis/reichlab/pymmwr.svg?style=flat-square
    :target: https://travis-ci.org/reichlab/pymmwr

.. image:: https://img.shields.io/pypi/v/pymmwr.svg?style=flat-square
    :target: https://pypi.python.org/pypi/pymmwr

`MMWR weeks <https://wwwn.cdc.gov/nndss/document/MMWR_Week_overview.pdf>`_ for
Python. Port of `MMWRWeek <https://github.com/jarad/MMWRweek>`_.

Weekdays go from Sunday (1) to Saturday (7). See ``./tests.py`` for usage
instructions.

.. code-block:: shell

   pip install pymmwr
